# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


class IncidentCreateRelationships(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.nullable_relationship_to_user import NullableRelationshipToUser

        return {
            "commander_user": (NullableRelationshipToUser,),
        }

    attribute_map = {
        "commander_user": "commander_user",
    }

    def __init__(self, commander_user, *args, **kwargs):
        """
        The relationships the incident will have with other resources once created.

        :param commander_user: Relationship to user.
        :type commander_user: NullableRelationshipToUser
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

        self.commander_user = commander_user

    @classmethod
    def _from_openapi_data(cls, commander_user, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(IncidentCreateRelationships, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        self.commander_user = commander_user
        return self
